
<!--
FrozenIsBool False
-->

#Itemizers

##Doc
----


> 
> The Objects helps ...
> 
> 

----

<small>
View the Itemizers notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Itemizers.ipynb)
</small>

